%define debug_package	%{nil}

%define rel	4

%define svn	0
%define pre	0
%if %svn
%define release		%mkrel 0.%svn.%rel
%define distname	%name-%svn.tar.lzma
%define dirname		%name
%else
%if %pre
%define release		%mkrel 0.%pre.%rel
%define distname	%name-%version.%pre.tar.gz
%define dirname		%name-%version.%pre
%else
%define release		%mkrel %rel
%define distname	%name-%version.tar.gz
%define dirname		%name-%version
%endif
%endif

# It's the same for releases, but different for pre-releases: please
# don't remove, even if it seems superfluous - AdamW 2008/03
%define fversion	%{version}

Summary:	Media center written in Python
Name:		elisa
Version:	0.3.5
Release:	%{release}
# For SVN:
# svn co https://code.fluendo.com/elisa/svn/trunk elisa
Source0:	http://elisa.fluendo.com/static/download/elisa/%{distname}
# Disable the auto-updater by default - AdamW 2008/03
Patch0:		elisa-0.3.5-updater.patch
License:	GPLv3 and MIT
Group:		Graphical desktop/Other
URL:		http://elisa.fluendo.com/
BuildArch:	noarch
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-buildroot
BuildRequires:	python
BuildRequires:	python-setuptools
BuildRequires:	python-devel
BuildRequires:	python-twisted
BuildRequires:	ImageMagick
BuildRequires:	desktop-file-utils
BuildRequires:	gstreamer0.10-python
Requires:	elisa-plugins-good
Requires:	elisa-plugins-bad
Requires:	elisa-core
Suggests:	elisa-plugins-ugly

%description
Elisa is a project to create an open source cross platform media center 
solution. Elisa runs on top of the GStreamer multimedia framework and 
takes full advantage of harware acceleration provided by modern graphic 
cards by using OpenGL APIs. In addition to personal video recorder 
functionality (PVR) and Music Jukebox support, Elisa will also 
interoperate with devices following the DLNA standard like Intel’s ViiV 
systems.

%package core
Summary:	Media center written in Python: core files
Group:		Development/Python
Requires:	pigment-python
Requires:	python-imaging
Requires:	python-twisted
Requires:	gnome-python-extras
Requires:	gstreamer0.10-python
Requires:	gstreamer0.10-plugins-base
Requires:	python-sqlite2
Requires:	pyxdg
Requires:	python-setuptools
Suggests:	gstreamer0.10-plugins-good
Suggests:	gstreamer0.10-plugins-bad
Suggests:	python-gpod
Suggests:	python-dbus

%description core
Elisa is a project to create an open source cross platform media center 
solution. Elisa runs on top of the GStreamer multimedia framework and 
takes full advantage of harware acceleration provided by modern graphic 
cards by using OpenGL APIs. In addition to personal video recorder 
functionality (PVR) and Music Jukebox support, Elisa will also 
interoperate with devices following the DLNA standard like Intel’s ViiV 
systems. This package contains the core Python files for Elisa. It is
split from the binaries for packaging reasons.

%prep
%setup -q -n %{dirname}
%patch0 -p1 -b .updater

# correct mandir
sed -i -e 's,man/man1,share/man/man1,g' setup.py

%build

%install
rm -rf %{buildroot}
python setup.py install --root=%{buildroot} --single-version-externally-managed --compile --optimize=2

# Install some stuff manually because the build process can't.
install -D -m644 data/%{name}.svg %{buildroot}%{_iconsdir}/hicolor/scalable/apps/%{name}.svg
install -D -m644 data/%{name}.png %{buildroot}%{_iconsdir}/hicolor/48x48/apps/%{name}.png

# Generate and install 32x32 and 16x16 icons.
mkdir -p %{buildroot}%{_iconsdir}/hicolor/{32x32,16x16}/apps

convert -scale 32 data/%{name}.png %{buildroot}%{_iconsdir}/hicolor/32x32/apps/%{name}.png
convert -scale 16 data/%{name}.png %{buildroot}%{_iconsdir}/hicolor/16x16/apps/%{name}.png

# Menu file
rm -f %{buildroot}%{_datadir}/applications/%{name}.desktop
cat > %{buildroot}%{_datadir}/applications/%{name}.desktop <<EOF
[Desktop Entry]
Name=Elisa Media Center
Comment=Play movies and songs on TV with remote
Exec=%{name} %U
StartupWMClass=%{name}
Icon=%{name}
Terminal=false
Type=Application
StartupNotify=true
Categories=GNOME;GTK;AudioVideo;Audio;Video;Player;X-MandrivaLinux-CrossDesktop;
X-Osso-Service=com.fluendo.elisa
EOF

#don't want these
rm -rf %{buildroot}%{py_puresitedir}/mswin32
rm -f %{buildroot}%{_datadir}/pixmaps/%{name}.png
rm -rf %{buildroot}%{_datadir}/mobile-basic-flash

# as there's three plugins packages that aren't interdependent, best
# let the core package own the plugins dir - AdamW 2008/02
mkdir -p %{buildroot}%{py_puresitedir}/%{name}/plugins

%post
%{update_menus}
%{update_icon_cache hicolor}

%postun
%{clean_menus}
%{clean_icon_cache hicolor}

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root)
%doc AUTHORS FAQ FAQ_EXTRA FIRST_RUN HACKING NEWS RELEASE TRANSLATORS
%{_bindir}/%{name}
%{_bindir}/%{name}-get
%{_datadir}/applications/%{name}.desktop
%{_iconsdir}/hicolor/*/apps/*
%{_mandir}/man1/%{name}.1*
%{_datadir}/dbus-1/services/*.service

%files core
%defattr(-,root,root)
%{py_puresitedir}/%{name}
%{py_puresitedir}/%{name}_plugin_core_setup.py*
%{py_puresitedir}/%{name}_generic_setup.py*
%{py_puresitedir}/%{name}-%{fversion}-py%{pyver}-nspkg.pth
%{py_puresitedir}/%{name}-%{fversion}-py%{pyver}.egg-info



%changelog
* Tue May 20 2008 Adam Williamson <awilliamson@mandriva.com> 0.3.5-4mdv2009.0
+ Revision: 209555
- elisa-core requires gstreamer0.10-plugins-base (Caio), suggests gstreamer0.10-plugins-good

* Thu Apr 17 2008 Adam Williamson <awilliamson@mandriva.com> 0.3.5-3mdv2009.0
+ Revision: 195036
- suggests elisa-plugins-ugly

* Sun Mar 23 2008 Anne Nicolas <anne.nicolas@mandriva.com> 0.3.5-2mdv2008.1
+ Revision: 189626
- Fix Mandriva menu for Elisa

* Tue Mar 18 2008 Adam Williamson <awilliamson@mandriva.com> 0.3.5-1mdv2008.1
+ Revision: 188614
- update file list
- clean up svn / pre-release conditionals
- new release 0.3.5

* Thu Mar 06 2008 Adam Williamson <awilliamson@mandriva.com> 0.3.4-2mdv2008.1
+ Revision: 180276
- drop bogus example MimeType line from the .desktop file (thanks neoclust)

* Tue Mar 04 2008 Adam Williamson <awilliamson@mandriva.com> 0.3.4-1mdv2008.1
+ Revision: 178929
- use Graphical desktop/Other as the group
- split into elisa and elisa-core to resolve dependency issue with plugins
- final 0.3.4

* Sun Mar 02 2008 Adam Williamson <awilliamson@mandriva.com> 0.3.4-0.rc3.3mdv2008.1
+ Revision: 177619
- requires elisa-plugins-bad (it shouldn't, but it does: tested by me and anne)

* Sat Mar 01 2008 Adam Williamson <awilliamson@mandriva.com> 0.3.4-0.rc3.2mdv2008.1
+ Revision: 177518
- requires plugins-good (won't launch without it: reported upstream)

* Sat Mar 01 2008 Adam Williamson <awilliamson@mandriva.com> 0.3.4-0.rc3.1mdv2008.1
+ Revision: 177152
- adjust file lists
- new release 0.3.4.rc3

* Fri Feb 29 2008 Adam Williamson <awilliamson@mandriva.com> 0.3.4-0.rc1.1mdv2008.1
+ Revision: 176633
- ok, that wasn't the right way to do it...
- correct fversion
- ghost plugins directory
- adjust spec for building core only (plugins now will be separate .src.rpms)
- new release 0.3.4rc1

* Tue Feb 26 2008 Adam Williamson <awilliamson@mandriva.com> 0.3.3.1-0.5106.2mdv2008.1
+ Revision: 175559
- fix a stray #
- add parameters so build pre-generates .pyo as well as .pyc files (per policy)

* Tue Feb 26 2008 Adam Williamson <awilliamson@mandriva.com> 0.3.3.1-0.5106.1mdv2008.1
+ Revision: 175245
- stupid, stupid upstream versioning...
- drop slideshow.patch (effectively merged upstream)
- new snapshot 5106

* Sat Feb 23 2008 Adam Williamson <awilliamson@mandriva.com> 0.3.3.1-0.5063.1mdv2008.1
+ Revision: 174022
- add slideshow.patch to make the slideshow plugin get installed (it seems to be required for elisa to launch)
- adapt to totally new buildsystem (all plugins still in main package for now)
- update to svn (to match new pigment and pigment-python)

* Wed Feb 13 2008 Adam Williamson <awilliamson@mandriva.com> 0.3.3-3mdv2008.1
+ Revision: 166846
- correct license (now GPLv3, not v2)
- including a pre-compiled .so file violates Mandriva packaging policy, noarch, and common decency, so remove this atrocity

* Wed Jan 30 2008 Adam Williamson <awilliamson@mandriva.com> 0.3.3-2mdv2008.1
+ Revision: 160137
- requires pyxdg and python-setuptools (thanks Anne and Erwan)

* Sat Jan 26 2008 Adam Williamson <awilliamson@mandriva.com> 0.3.3-1mdv2008.1
+ Revision: 158188
- br gstreamer0.10-python
- adjust spec
- new release 0.3.3

* Fri Dec 28 2007 Adam Williamson <awilliamson@mandriva.com> 0.3.2-1mdv2008.1
+ Revision: 138691
- correct file list
- drop fixhal.patch, merged upstream
- new release 0.3.2

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tvignaud@mandriva.com>
    - kill re-definition of %%buildroot on Pixel's request

* Fri Jun 08 2007 Frederic Crozat <fcrozat@mandriva.com> 0.1.6-2mdv2008.0
+ Revision: 37468
- Patch0 (SVN): fix hal plugin
- add dependency on dbus-python and python-setuptools

  + Adam Williamson <awilliamson@mandriva.com>
    - correct URL
    - use %%pyver, do not hardcode 2.5

* Thu May 10 2007 Adam Williamson <awilliamson@mandriva.com> 0.1.6-1mdv2008.0
+ Revision: 26134
- noarch
- BuildRequires desktop-file-utils
- Import elisa

